{% load enterprise %}
{% if enterprise_customer.branding_configuration %}
    <img class="enterprise-logo" src="{{ enterprise_customer.branding_configuration.logo.url }}" alt="{{ enterprise_customer.name }}"/>
{% endif %}
{% if text_override_available %}
  <p class="partnered-text">
    {{ left_sidebar_text|only_safe_html }}
  </p>
{% else %}
  <p class="partnered-text">
    {{ welcome_text }}
  </p>
  <p class="partnered-text">
    {{ enterprise_welcome_text|only_safe_html }}
  </p>
{% endif %}
