"""
Your project description goes here.
"""

from __future__ import absolute_import, unicode_literals

__version__ = "1.8.1"

default_app_config = "enterprise.apps.EnterpriseConfig"  # pylint: disable=invalid-name
